@@ -10,17 +10,29 @@ class TODO(drink.Page):
 
     mime = "note"
 
-    editable_fields = {
-        'title': drink.types.Text("Title", group="a"),
-        'content': drink.types.TextArea("Summary", group="b"),
-        'description': drink.types.Text('Description'),
-        #'date': drink.types.Date,
-    }
+    default_action = "edit"
 
     content = ''
 
-    def view(self):
-        drink.rdr(self.path+'edit')
+    editable_fields = {
+        'title': drink.types.Text("Title", group="a"),
+        'date': drink.types.Date("Scheduled for", group="b"),
+        'content': drink.types.TextArea("Summary", group="c"),
+        #'description': drink.types.Text('Short description', group="a"),
+    }
+
+    @property
+    def description(self):
+        if len(self.content) > 100:
+            txt = self.content[:100].rsplit(None, 1)[0]+" ..."
+        else:
+            txt = self.content
+        if self.date:
+            txt = "(%s) %s"%(self.date, txt)
+
+        return txt
+
+    date = ''
 
 
 class TODOList(drink.ListPage):
